# Changelog

## 0.1.0-alpha.10 (2025-04-28)

Full Changelog: [v0.1.0-alpha.9...v0.1.0-alpha.10](https://github.com/sureapp/verify-python/compare/v0.1.0-alpha.9...v0.1.0-alpha.10)

### Features

* **api:** api update ([700cba4](https://github.com/sureapp/verify-python/commit/700cba4af1a0c44e9004e65c4635ca7bef7278b3))
* **api:** api update ([4c2d22f](https://github.com/sureapp/verify-python/commit/4c2d22f9fc1105c5a09d683a073e6819a0def9a5))
* **api:** api update ([ab03627](https://github.com/sureapp/verify-python/commit/ab036275b859d15b8a7412f62abe8f84102724eb))
* **api:** api update ([6f6c41c](https://github.com/sureapp/verify-python/commit/6f6c41c48bdd4c9f1a91d2e2a7b3f1d20a7f2296))
* **api:** manual updates ([3f27e73](https://github.com/sureapp/verify-python/commit/3f27e731c260f3d3a214a584bd5c2d9332944a41))


### Bug Fixes

* **pydantic v1:** more robust ModelField.annotation check ([a0eb865](https://github.com/sureapp/verify-python/commit/a0eb8652ec016269fb902caee0fce6e94d7ce21d))


### Chores

* broadly detect json family of content-type headers ([4679a5b](https://github.com/sureapp/verify-python/commit/4679a5b5b260241ed99649a8f10af025e66a15da))
* **ci:** add timeout thresholds for CI jobs ([7d83dbd](https://github.com/sureapp/verify-python/commit/7d83dbde32f08dfca937688a9a3a9ab34ebdddaa))
* **ci:** only use depot for staging repos ([0c093bd](https://github.com/sureapp/verify-python/commit/0c093bd3d24a64b74a04bd2e2a8b3fd43df199bd))
* **internal:** codegen related update ([154701e](https://github.com/sureapp/verify-python/commit/154701e60bed288d9bcf0767f80667f12f49aa77))
* **internal:** fix list file params ([5007e7e](https://github.com/sureapp/verify-python/commit/5007e7e0977cd38c6dd8cc30674a43e9aa5f0a5b))
* **internal:** import reformatting ([73c385a](https://github.com/sureapp/verify-python/commit/73c385a625e19b1a5a680dc7c5158f4d690949ae))
* **internal:** minor formatting changes ([5ef6fbb](https://github.com/sureapp/verify-python/commit/5ef6fbb489f5d02031a8afb0064c0e3b4b1c6eb4))
* **internal:** refactor retries to not use recursion ([25ef6e7](https://github.com/sureapp/verify-python/commit/25ef6e764f8a293027ed71ed82bc84a105df4047))
* **internal:** update models test ([b9e82d4](https://github.com/sureapp/verify-python/commit/b9e82d46e43f06eaddf68828a179bca8c8c53f65))

## 0.1.0-alpha.9 (2025-04-18)

Full Changelog: [v0.1.0-alpha.8...v0.1.0-alpha.9](https://github.com/sureapp/verify-python/compare/v0.1.0-alpha.8...v0.1.0-alpha.9)

### Features

* **api:** api update ([00fe47a](https://github.com/sureapp/verify-python/commit/00fe47ae81a210c13e4be842d2d85a221f0b1070))
* **api:** api update ([dbcee46](https://github.com/sureapp/verify-python/commit/dbcee464624fb3414b013c7d6df4a8382330560e))


### Chores

* update SDK settings ([d3701fe](https://github.com/sureapp/verify-python/commit/d3701feec315f0cbeb2d61221545976ee1ef10bc))

## 0.1.0-alpha.8 (2025-04-17)

Full Changelog: [v0.1.0-alpha.7...v0.1.0-alpha.8](https://github.com/sureapp/verify-python/compare/v0.1.0-alpha.7...v0.1.0-alpha.8)

### Features

* Added more examples and lint ([465f310](https://github.com/sureapp/verify-python/commit/465f310377e63bf49bab2025732f62e40d7a60dc))

## 0.1.0-alpha.7 (2025-04-17)

Full Changelog: [v0.1.0-alpha.6...v0.1.0-alpha.7](https://github.com/sureapp/verify-python/compare/v0.1.0-alpha.6...v0.1.0-alpha.7)

### Features

* **api:** update via SDK Studio ([f0f14b2](https://github.com/sureapp/verify-python/commit/f0f14b2d8c5b17a98b44c1fed79f85205d70f8af))
* **api:** update via SDK Studio ([524a9b0](https://github.com/sureapp/verify-python/commit/524a9b0395068f2684066a0ac38d7e95576f4309))


### Chores

* **internal:** base client updates ([f057ee8](https://github.com/sureapp/verify-python/commit/f057ee8f5cde01bbdd96b54014667f990c1e1325))
* **internal:** bump pyright version ([fc38b12](https://github.com/sureapp/verify-python/commit/fc38b12b37c305e1c1323fe3ca4be61004674394))

## 0.1.0-alpha.6 (2025-04-16)

Full Changelog: [v0.1.0-alpha.5...v0.1.0-alpha.6](https://github.com/sureapp/verify-python/compare/v0.1.0-alpha.5...v0.1.0-alpha.6)

### Features

* **api:** update via SDK Studio ([1016c8a](https://github.com/sureapp/verify-python/commit/1016c8aca9d88872757d6f16a469c15da1c52d06))
* **api:** update via SDK Studio ([6288aa5](https://github.com/sureapp/verify-python/commit/6288aa52fedb7abaf1310c687f827147ef53ce96))

## 0.1.0-alpha.5 (2025-04-16)

Full Changelog: [v0.1.0-alpha.4...v0.1.0-alpha.5](https://github.com/sureapp/verify-python/compare/v0.1.0-alpha.4...v0.1.0-alpha.5)

### Features

* **api:** update via SDK Studio ([3369edb](https://github.com/sureapp/verify-python/commit/3369edbb5260d041f4c42fe212c95c9e80887083))

## 0.1.0-alpha.4 (2025-04-16)

Full Changelog: [v0.1.0-alpha.3...v0.1.0-alpha.4](https://github.com/sureapp/verify-python/compare/v0.1.0-alpha.3...v0.1.0-alpha.4)

### Features

* **api:** update via SDK Studio ([3766129](https://github.com/sureapp/verify-python/commit/3766129dc3fbed084dcb458c8c12bfca544cfc9a))
* **examples:** add embedded and hosted verification session examples; refactor community data setup ([62f694a](https://github.com/sureapp/verify-python/commit/62f694a7d4cbd71509de69814377514aeaa39fac))
* Lint ([ce80e9a](https://github.com/sureapp/verify-python/commit/ce80e9a73a33fb06a363f669886fade483164714))
* Lint and format ([dfafa6d](https://github.com/sureapp/verify-python/commit/dfafa6d5203424eddc59d76c217f04fa052f79f1))

## 0.1.0-alpha.3 (2025-04-16)

Full Changelog: [v0.1.0-alpha.2...v0.1.0-alpha.3](https://github.com/sureapp/verify-python/compare/v0.1.0-alpha.2...v0.1.0-alpha.3)

### Features

* **api:** update via SDK Studio ([a9e7e4d](https://github.com/sureapp/verify-python/commit/a9e7e4d687481e1ad98fda224aa672199bc0427e))

## 0.1.0-alpha.2 (2025-04-16)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/sureapp/verify-python/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Features

* **api:** update via SDK Studio ([dc5b1f5](https://github.com/sureapp/verify-python/commit/dc5b1f5adc2c86d2fba02d4757ca4c4d00cb6fab))


### Bug Fixes

* **perf:** optimize some hot paths ([d0fa312](https://github.com/sureapp/verify-python/commit/d0fa3124e28a8255459c0ad9a360bbae000da959))
* **perf:** skip traversing types for NotGiven values ([67cc6cc](https://github.com/sureapp/verify-python/commit/67cc6ccf786d01a6f4332540604287d2b87ddb38))


### Chores

* **client:** minor internal fixes ([9da88fb](https://github.com/sureapp/verify-python/commit/9da88fbfa61beda31f280a36bd1eebbe10f6dc2f))
* **internal:** update pyright settings ([3132102](https://github.com/sureapp/verify-python/commit/313210238e57f98f636a4d184d4ae7ca0bea60c0))


### Documentation

* community data example added ([0916925](https://github.com/sureapp/verify-python/commit/0916925ebf38aab70166ebf40a74e74959a95e43))

## 0.1.0-alpha.1 (2025-04-11)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/sureapp/verify-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** update via SDK Studio ([41e17cb](https://github.com/sureapp/verify-python/commit/41e17cb0cbe3e2bffa0590f99202c35b3798f5f9))
* **api:** update via SDK Studio ([7769ace](https://github.com/sureapp/verify-python/commit/7769ace5915cd2dece3faa1ca25ec7524267f9e8))
* **auth:** Added JWT signer ([#3](https://github.com/sureapp/verify-python/issues/3)) ([09d31bf](https://github.com/sureapp/verify-python/commit/09d31bf334fdfa6df5ae9288f8d110e6cf8dc3ae))


### Chores

* go live ([a336851](https://github.com/sureapp/verify-python/commit/a33685102fc50125bacf34a4c868c94fc6386832))
* **internal:** expand CI branch coverage ([7ea29c2](https://github.com/sureapp/verify-python/commit/7ea29c2d95f46b35a8203a4c5e25612a67e76e11))
* **internal:** reduce CI branch coverage ([1408388](https://github.com/sureapp/verify-python/commit/1408388e7473ae1fd2a0f93ecef28bbf0156a35b))
* update SDK settings ([#1](https://github.com/sureapp/verify-python/issues/1)) ([3638998](https://github.com/sureapp/verify-python/commit/3638998cd1457895403d0f0a7f991d1e9b44a316))
